mailtoplone.contentrules TODO
=============================

:Author:    Hans-Peter Locher
:Date:      $Date$
:Revision:  $Revision$

Conditions
----------

emailheader
***********

- optional go recursively through email (use walk to yield all parts)
- user should be able to define recursive yes or no (checkbox)

::

 vim: set ft=rst tw=75 nocin nosi ai sw=4 ts=4 expandtab:
